summaryrefslogtreecommitdiffstats
path: root/tools/designer/designer
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-02-13 17:43:39 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2012-02-13 17:43:39 -0600
commit359640943bcf155faa9a067dde9e00a123276290 (patch)
treefb3d55ea5e18949042fb0064123fb73d2b1eb932 /tools/designer/designer
parenta829bcdc533e154000803d517200d32fe762e85c (diff)
downloadtqt3-359640943bcf155faa9a067dde9e00a123276290.tar.gz
tqt3-359640943bcf155faa9a067dde9e00a123276290.zip
Automated update from Qt3
Diffstat (limited to 'tools/designer/designer')
-rw-r--r--tools/designer/designer/actiondnd.cpp2
-rw-r--r--tools/designer/designer/actiondnd.h12
-rw-r--r--tools/designer/designer/actioneditorimpl.h2
-rw-r--r--tools/designer/designer/actionlistview.h2
-rw-r--r--tools/designer/designer/asciivalidator.h2
-rw-r--r--tools/designer/designer/command.h2
-rw-r--r--tools/designer/designer/connectionitems.h12
-rw-r--r--tools/designer/designer/connectiontable.h2
-rw-r--r--tools/designer/designer/customwidgeteditorimpl.h2
-rw-r--r--tools/designer/designer/database.h4
-rw-r--r--tools/designer/designer/database2.h4
-rw-r--r--tools/designer/designer/dbconnectionimpl.h2
-rw-r--r--tools/designer/designer/dbconnectionsimpl.h2
-rw-r--r--tools/designer/designer/designerapp.cpp8
-rw-r--r--tools/designer/designer/editfunctionsimpl.h2
-rw-r--r--tools/designer/designer/formfile.h2
-rw-r--r--tools/designer/designer/formsettingsimpl.h2
-rw-r--r--tools/designer/designer/formwindow.h2
-rw-r--r--tools/designer/designer/hierarchyview.h6
-rw-r--r--tools/designer/designer/iconvieweditorimpl.h2
-rw-r--r--tools/designer/designer/layout.h6
-rw-r--r--tools/designer/designer/listboxdnd.h2
-rw-r--r--tools/designer/designer/listboxeditorimpl.h2
-rw-r--r--tools/designer/designer/listboxrename.h2
-rw-r--r--tools/designer/designer/listdnd.h2
-rw-r--r--tools/designer/designer/listviewdnd.h2
-rw-r--r--tools/designer/designer/listvieweditorimpl.h2
-rw-r--r--tools/designer/designer/mainwindow.cpp4
-rw-r--r--tools/designer/designer/mainwindow.h4
-rw-r--r--tools/designer/designer/menubareditor.h4
-rw-r--r--tools/designer/designer/multilineeditorimpl.h6
-rw-r--r--tools/designer/designer/newformimpl.h2
-rw-r--r--tools/designer/designer/orderindicator.h2
-rw-r--r--tools/designer/designer/outputwindow.h2
-rw-r--r--tools/designer/designer/paletteeditoradvancedimpl.h2
-rw-r--r--tools/designer/designer/paletteeditorimpl.h2
-rw-r--r--tools/designer/designer/pixmapchooser.h4
-rw-r--r--tools/designer/designer/popupmenueditor.h4
-rw-r--r--tools/designer/designer/previewframe.h4
-rw-r--r--tools/designer/designer/previewwidgetimpl.h2
-rw-r--r--tools/designer/designer/project.h2
-rw-r--r--tools/designer/designer/projectsettingsimpl.h2
-rw-r--r--tools/designer/designer/propertyeditor.h48
-rw-r--r--tools/designer/designer/qcompletionedit.h2
-rw-r--r--tools/designer/designer/resource.cpp4
-rw-r--r--tools/designer/designer/sizehandle.h2
-rw-r--r--tools/designer/designer/sourceeditor.h2
-rw-r--r--tools/designer/designer/sourcefile.h2
-rw-r--r--tools/designer/designer/startdialogimpl.h4
-rw-r--r--tools/designer/designer/styledbutton.h2
-rw-r--r--tools/designer/designer/tableeditorimpl.h2
-rw-r--r--tools/designer/designer/timestamp.h2
-rw-r--r--tools/designer/designer/variabledialogimpl.h2
-rw-r--r--tools/designer/designer/widgetaction.h2
-rw-r--r--tools/designer/designer/widgetfactory.h28
-rw-r--r--tools/designer/designer/wizardeditorimpl.h2
-rw-r--r--tools/designer/designer/workspace.h2
57 files changed, 122 insertions, 122 deletions
diff --git a/tools/designer/designer/actiondnd.cpp b/tools/designer/designer/actiondnd.cpp
index 1f9e8328..def64548 100644
--- a/tools/designer/designer/actiondnd.cpp
+++ b/tools/designer/designer/actiondnd.cpp
@@ -138,7 +138,7 @@ void TQDesignerAction::remove()
class TQDesignerIndicatorWidget : public TQWidget
{
- Q_OBJECT
+ TQ_OBJECT
public:
TQDesignerIndicatorWidget( TQWidget *p )
diff --git a/tools/designer/designer/actiondnd.h b/tools/designer/designer/actiondnd.h
index ba21ff5a..41578424 100644
--- a/tools/designer/designer/actiondnd.h
+++ b/tools/designer/designer/actiondnd.h
@@ -52,7 +52,7 @@ class TQPopupMenu;
class ActionDrag : public TQStoredDrag
{
- Q_OBJECT
+ TQ_OBJECT
public:
ActionDrag(const TQString &type, TQAction *action, TQWidget *source);
@@ -74,7 +74,7 @@ private:
class TQDesignerActionGroup : public TQActionGroup
{
- Q_OBJECT
+ TQ_OBJECT
public:
TQDesignerActionGroup( TQObject *parent )
@@ -109,7 +109,7 @@ private:
class TQDesignerAction : public TQAction
{
- Q_OBJECT
+ TQ_OBJECT
public:
TQDesignerAction( TQObject *parent )
@@ -145,7 +145,7 @@ private:
class TQDesignerToolBarSeparator : public TQWidget
{
- Q_OBJECT
+ TQ_OBJECT
public:
TQDesignerToolBarSeparator( Orientation, TQToolBar *parent, const char* name=0 );
@@ -164,7 +164,7 @@ private:
class TQSeparatorAction : public TQAction
{
- Q_OBJECT
+ TQ_OBJECT
public:
TQSeparatorAction( TQObject *parent );
@@ -183,7 +183,7 @@ private:
class TQDesignerToolBar : public TQToolBar
{
- Q_OBJECT
+ TQ_OBJECT
public:
TQDesignerToolBar( TQMainWindow *mw );
diff --git a/tools/designer/designer/actioneditorimpl.h b/tools/designer/designer/actioneditorimpl.h
index a04b2e48..d1279271 100644
--- a/tools/designer/designer/actioneditorimpl.h
+++ b/tools/designer/designer/actioneditorimpl.h
@@ -42,7 +42,7 @@ class ActionItem;
class ActionEditor : public ActionEditorBase
{
- Q_OBJECT
+ TQ_OBJECT
public:
ActionEditor( TQWidget* parent = 0, const char* name = 0, WFlags fl = 0 );
diff --git a/tools/designer/designer/actionlistview.h b/tools/designer/designer/actionlistview.h
index d9663368..59f769ab 100644
--- a/tools/designer/designer/actionlistview.h
+++ b/tools/designer/designer/actionlistview.h
@@ -65,7 +65,7 @@ private:
class ActionListView : public TQListView
{
- Q_OBJECT
+ TQ_OBJECT
public:
ActionListView( TQWidget *parent = 0, const char *name = 0 );
diff --git a/tools/designer/designer/asciivalidator.h b/tools/designer/designer/asciivalidator.h
index d3afdfd2..ee6aca39 100644
--- a/tools/designer/designer/asciivalidator.h
+++ b/tools/designer/designer/asciivalidator.h
@@ -40,7 +40,7 @@
class AsciiValidator: public TQValidator
{
- Q_OBJECT
+ TQ_OBJECT
public:
AsciiValidator( TQObject * parent, const char *name = 0 );
AsciiValidator( bool funcName, TQObject * parent, const char *name = 0 );
diff --git a/tools/designer/designer/command.h b/tools/designer/designer/command.h
index d6eef4fe..6fc0aa5c 100644
--- a/tools/designer/designer/command.h
+++ b/tools/designer/designer/command.h
@@ -156,7 +156,7 @@ private:
class CommandHistory : public TQObject
{
- Q_OBJECT
+ TQ_OBJECT
public:
CommandHistory( int s );
diff --git a/tools/designer/designer/connectionitems.h b/tools/designer/designer/connectionitems.h
index 60407ae5..40878c44 100644
--- a/tools/designer/designer/connectionitems.h
+++ b/tools/designer/designer/connectionitems.h
@@ -48,7 +48,7 @@ class ConnectionContainer;
class ConnectionItem : public TQObject,
public TQComboTableItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
ConnectionItem( TQTable *table, FormWindow *fw );
@@ -83,7 +83,7 @@ private:
class SenderItem : public ConnectionItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
SenderItem( TQTable *table, FormWindow *fw );
@@ -102,7 +102,7 @@ private slots:
class ReceiverItem : public ConnectionItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
ReceiverItem( TQTable *table, FormWindow *fw );
@@ -121,7 +121,7 @@ private slots:
class SignalItem : public ConnectionItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
SignalItem( TQTable *table, FormWindow *fw );
@@ -138,7 +138,7 @@ signals:
class SlotItem : public ConnectionItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
SlotItem( TQTable *table, FormWindow *fw );
@@ -166,7 +166,7 @@ private:
class ConnectionContainer : public TQObject
{
- Q_OBJECT
+ TQ_OBJECT
public:
ConnectionContainer( TQObject *parent, SenderItem *i1, SignalItem *i2,
diff --git a/tools/designer/designer/connectiontable.h b/tools/designer/designer/connectiontable.h
index 6a11ce9f..9e556447 100644
--- a/tools/designer/designer/connectiontable.h
+++ b/tools/designer/designer/connectiontable.h
@@ -38,7 +38,7 @@
class ConnectionTable : public TQTable
{
- Q_OBJECT
+ TQ_OBJECT
public:
ConnectionTable( TQWidget *parent, const char *name );
diff --git a/tools/designer/designer/customwidgeteditorimpl.h b/tools/designer/designer/customwidgeteditorimpl.h
index fd645976..49f28027 100644
--- a/tools/designer/designer/customwidgeteditorimpl.h
+++ b/tools/designer/designer/customwidgeteditorimpl.h
@@ -46,7 +46,7 @@ class MainWindow;
class CustomWidgetEditor : public CustomWidgetEditorBase
{
- Q_OBJECT
+ TQ_OBJECT
public:
CustomWidgetEditor( TQWidget *parent , MainWindow *mw);
diff --git a/tools/designer/designer/database.h b/tools/designer/designer/database.h
index 3008f783..0af7a92f 100644
--- a/tools/designer/designer/database.h
+++ b/tools/designer/designer/database.h
@@ -65,7 +65,7 @@ protected:
class TQDesignerDataBrowser : public TQDataBrowser, public DatabaseSupport
{
- Q_OBJECT
+ TQ_OBJECT
public:
TQDesignerDataBrowser( TQWidget *parent, const char *name );
@@ -76,7 +76,7 @@ protected:
class TQDesignerDataView : public TQDataView, public DatabaseSupport
{
- Q_OBJECT
+ TQ_OBJECT
public:
TQDesignerDataView( TQWidget *parent, const char *name );
diff --git a/tools/designer/designer/database2.h b/tools/designer/designer/database2.h
index fade3b8e..df7c294b 100644
--- a/tools/designer/designer/database2.h
+++ b/tools/designer/designer/database2.h
@@ -65,7 +65,7 @@ protected:
class TQDesignerDataBrowser2 : public TQDataBrowser, public DatabaseSupport2
{
- Q_OBJECT
+ TQ_OBJECT
public:
TQDesignerDataBrowser2( TQWidget *parent, const char *name );
@@ -76,7 +76,7 @@ protected:
class TQDesignerDataView2 : public TQDataView, public DatabaseSupport2
{
- Q_OBJECT
+ TQ_OBJECT
public:
TQDesignerDataView2( TQWidget *parent, const char *name );
diff --git a/tools/designer/designer/dbconnectionimpl.h b/tools/designer/designer/dbconnectionimpl.h
index c3c7b7f9..fbf379d3 100644
--- a/tools/designer/designer/dbconnectionimpl.h
+++ b/tools/designer/designer/dbconnectionimpl.h
@@ -42,7 +42,7 @@ class TQGridLayout;
class DatabaseConnectionEditor : public DatabaseConnectionEditorBase
{
- Q_OBJECT
+ TQ_OBJECT
public:
DatabaseConnectionEditor( DatabaseConnection* connection, TQWidget* parent = 0,
diff --git a/tools/designer/designer/dbconnectionsimpl.h b/tools/designer/designer/dbconnectionsimpl.h
index ef3e50bd..3b65ed60 100644
--- a/tools/designer/designer/dbconnectionsimpl.h
+++ b/tools/designer/designer/dbconnectionsimpl.h
@@ -41,7 +41,7 @@ class Project;
class DatabaseConnectionsEditor : public DatabaseConnectionBase
{
- Q_OBJECT
+ TQ_OBJECT
public:
DatabaseConnectionsEditor( Project *pro, TQWidget* parent = 0,
diff --git a/tools/designer/designer/designerapp.cpp b/tools/designer/designer/designerapp.cpp
index 06e8edab..f3347446 100644
--- a/tools/designer/designer/designerapp.cpp
+++ b/tools/designer/designer/designerapp.cpp
@@ -105,16 +105,16 @@ TQString DesignerApplication::settingsKey()
{
if ( !settings_key )
settings_key = new TQString( "/TQt Designer/" +
- TQString::number( (QT_VERSION >> 16) & 0xff ) +
- "." + TQString::number( (QT_VERSION >> 8) & 0xff ) + "/" );
+ TQString::number( (TQT_VERSION >> 16) & 0xff ) +
+ "." + TQString::number( (TQT_VERSION >> 8) & 0xff ) + "/" );
return *settings_key;
}
TQString DesignerApplication::oldSettingsKey()
{
if ( !old_settings_key ) {
- int majorVer = (QT_VERSION >> 16) & 0xff;
- int minorVer = (QT_VERSION >> 8) & 0xff;
+ int majorVer = (TQT_VERSION >> 16) & 0xff;
+ int minorVer = (TQT_VERSION >> 8) & 0xff;
// If minorVer is 0 (e.g. 4.0) then we don't want to read the
// old settings, too much might have changed.
diff --git a/tools/designer/designer/editfunctionsimpl.h b/tools/designer/designer/editfunctionsimpl.h
index d852afcf..e661dedd 100644
--- a/tools/designer/designer/editfunctionsimpl.h
+++ b/tools/designer/designer/editfunctionsimpl.h
@@ -44,7 +44,7 @@ class TQListViewItem;
class EditFunctions : public EditFunctionsBase
{
- Q_OBJECT
+ TQ_OBJECT
public:
EditFunctions( TQWidget *parent, FormWindow *fw, bool showOnlySlots = FALSE );
diff --git a/tools/designer/designer/formfile.h b/tools/designer/designer/formfile.h
index 8cc493c3..d0dbe537 100644
--- a/tools/designer/designer/formfile.h
+++ b/tools/designer/designer/formfile.h
@@ -44,7 +44,7 @@ class SourceEditor;
class FormFile : public TQObject
{
- Q_OBJECT
+ TQ_OBJECT
friend class SourceEditor;
public:
diff --git a/tools/designer/designer/formsettingsimpl.h b/tools/designer/designer/formsettingsimpl.h
index 950b2f21..4b797390 100644
--- a/tools/designer/designer/formsettingsimpl.h
+++ b/tools/designer/designer/formsettingsimpl.h
@@ -40,7 +40,7 @@ class FormWindow;
class FormSettings : public FormSettingsBase
{
- Q_OBJECT
+ TQ_OBJECT
public:
FormSettings( TQWidget *parent, FormWindow *fw );
diff --git a/tools/designer/designer/formwindow.h b/tools/designer/designer/formwindow.h
index b294d679..130d719a 100644
--- a/tools/designer/designer/formwindow.h
+++ b/tools/designer/designer/formwindow.h
@@ -71,7 +71,7 @@ class OrderIndicator;
class FormWindow : public TQWidget
{
- Q_OBJECT
+ TQ_OBJECT
Q_PROPERTY( TQString fileName READ fileName WRITE setFileName )
public:
diff --git a/tools/designer/designer/hierarchyview.h b/tools/designer/designer/hierarchyview.h
index 29c20055..faa097e0 100644
--- a/tools/designer/designer/hierarchyview.h
+++ b/tools/designer/designer/hierarchyview.h
@@ -104,7 +104,7 @@ private:
class HierarchyList : public TQListView
{
- Q_OBJECT
+ TQ_OBJECT
public:
HierarchyList( TQWidget *parent, FormWindow *fw, bool doConnects = TRUE );
@@ -156,7 +156,7 @@ protected:
class FormDefinitionView : public HierarchyList
{
- Q_OBJECT
+ TQ_OBJECT
public:
FormDefinitionView( TQWidget *parent, FormWindow *fw );
@@ -189,7 +189,7 @@ private:
class HierarchyView : public TQTabWidget
{
- Q_OBJECT
+ TQ_OBJECT
public:
HierarchyView( TQWidget *parent );
diff --git a/tools/designer/designer/iconvieweditorimpl.h b/tools/designer/designer/iconvieweditorimpl.h
index dc995147..d9e04a9a 100644
--- a/tools/designer/designer/iconvieweditorimpl.h
+++ b/tools/designer/designer/iconvieweditorimpl.h
@@ -40,7 +40,7 @@ class FormWindow;
class IconViewEditor : public IconViewEditorBase
{
- Q_OBJECT
+ TQ_OBJECT
public:
IconViewEditor( TQWidget *parent, TQWidget *editWidget, FormWindow *fw );
diff --git a/tools/designer/designer/layout.h b/tools/designer/designer/layout.h
index 97bd997b..85b5b6af 100644
--- a/tools/designer/designer/layout.h
+++ b/tools/designer/designer/layout.h
@@ -47,7 +47,7 @@ class TQPaintEvent;
class Layout : public TQObject
{
- Q_OBJECT
+ TQ_OBJECT
public:
Layout( const TQWidgetList &wl, TQWidget *p, FormWindow *fw, TQWidget *lb, bool doSetup = TRUE, bool splitter = FALSE );
@@ -124,7 +124,7 @@ protected:
class Spacer : public TQWidget
{
- Q_OBJECT
+ TQ_OBJECT
Q_OVERRIDE( TQCString name )
Q_PROPERTY( Orientation orientation READ orientation WRITE setOrientation )
@@ -168,7 +168,7 @@ protected:
class TQDesignerGridLayout : public TQGridLayout
{
- Q_OBJECT
+ TQ_OBJECT
public:
TQDesignerGridLayout( TQWidget *parent ) : TQGridLayout( parent ){};
TQDesignerGridLayout( TQLayout *parentLayout ) : TQGridLayout( parentLayout ){};
diff --git a/tools/designer/designer/listboxdnd.h b/tools/designer/designer/listboxdnd.h
index 50e8db89..546f6a2a 100644
--- a/tools/designer/designer/listboxdnd.h
+++ b/tools/designer/designer/listboxdnd.h
@@ -42,7 +42,7 @@ typedef TQPtrList<TQListBoxItem> ListBoxItemList;
class ListBoxDnd : public ListDnd
{
- Q_OBJECT
+ TQ_OBJECT
public:
// dragModes are enumerated in ListDnd
ListBoxDnd( TQListBox * eventSource, const char * name = 0 );
diff --git a/tools/designer/designer/listboxeditorimpl.h b/tools/designer/designer/listboxeditorimpl.h
index d4375fb8..2f84eaf9 100644
--- a/tools/designer/designer/listboxeditorimpl.h
+++ b/tools/designer/designer/listboxeditorimpl.h
@@ -41,7 +41,7 @@ class FormWindow;
class ListBoxEditor : public ListBoxEditorBase
{
- Q_OBJECT
+ TQ_OBJECT
public:
ListBoxEditor( TQWidget *parent, TQWidget *editWidget, FormWindow *fw );
diff --git a/tools/designer/designer/listboxrename.h b/tools/designer/designer/listboxrename.h
index e857fcfe..8606dea4 100644
--- a/tools/designer/designer/listboxrename.h
+++ b/tools/designer/designer/listboxrename.h
@@ -41,7 +41,7 @@ class TQLineEdit;
class ListBoxRename : public TQObject
{
- Q_OBJECT
+ TQ_OBJECT
public:
ListBoxRename( TQListBox * eventSource, const char * name = 0 );
bool eventFilter( TQObject *, TQEvent * event );
diff --git a/tools/designer/designer/listdnd.h b/tools/designer/designer/listdnd.h
index 08820f70..df93f5cc 100644
--- a/tools/designer/designer/listdnd.h
+++ b/tools/designer/designer/listdnd.h
@@ -39,7 +39,7 @@
class ListDnd : public TQObject
{
- Q_OBJECT
+ TQ_OBJECT
public:
enum DragMode { None = 0, External = 1, Internal = 2, Both = 3, Move = 4, NullDrop = 8 };
ListDnd( TQScrollView * eventSource, const char * name = 0 );
diff --git a/tools/designer/designer/listviewdnd.h b/tools/designer/designer/listviewdnd.h
index dee4ce43..a58773d7 100644
--- a/tools/designer/designer/listviewdnd.h
+++ b/tools/designer/designer/listviewdnd.h
@@ -44,7 +44,7 @@ typedef TQPtrList<TQListViewItem> ListViewItemList;
class ListViewDnd : public ListDnd
{
- Q_OBJECT
+ TQ_OBJECT
public:
enum DragMode { Flat = 16 }; // see ListDnd::DragMode
diff --git a/tools/designer/designer/listvieweditorimpl.h b/tools/designer/designer/listvieweditorimpl.h
index f3258fb6..194e1f81 100644
--- a/tools/designer/designer/listvieweditorimpl.h
+++ b/tools/designer/designer/listvieweditorimpl.h
@@ -44,7 +44,7 @@ class FormWindow;
class ListViewEditor : public ListViewEditorBase
{
- Q_OBJECT
+ TQ_OBJECT
public:
ListViewEditor( TQWidget *parent, TQListView *lv, FormWindow *fw );
diff --git a/tools/designer/designer/mainwindow.cpp b/tools/designer/designer/mainwindow.cpp
index 822f35eb..4f22fb8b 100644
--- a/tools/designer/designer/mainwindow.cpp
+++ b/tools/designer/designer/mainwindow.cpp
@@ -820,7 +820,7 @@ void MainWindow::helpAbout()
LanguageInterface *iface = MetaDataBase::languageInterface( eProject->language() );
dlg.aboutLicense->setText( iface->aboutText() );
}
- dlg.aboutVersion->setText(TQString("Version ") + TQString(QT_VERSION_STR));
+ dlg.aboutVersion->setText(TQString("Version ") + TQString(TQT_VERSION_STR));
dlg.resize( dlg.width(), dlg.layout()->heightForWidth(dlg.width()) );
dlg.exec();
}
@@ -1306,7 +1306,7 @@ void MainWindow::insertFormWindow( FormWindow *fw )
}
fw->show();
fw->currentToolChanged();
- if ( fw->caption().isEmpty() && qstrlen( fw->name() ) )
+ if ( fw->caption().isEmpty() && tqstrlen( fw->name() ) )
fw->setCaption( fw->name() );
fw->mainContainer()->setCaption( fw->caption() );
WidgetFactory::saveDefaultProperties( fw->mainContainer(),
diff --git a/tools/designer/designer/mainwindow.h b/tools/designer/designer/mainwindow.h
index 602f8a56..b18618a9 100644
--- a/tools/designer/designer/mainwindow.h
+++ b/tools/designer/designer/mainwindow.h
@@ -83,7 +83,7 @@ class Preferences;
class MainWindow : public TQMainWindow
{
- Q_OBJECT
+ TQ_OBJECT
public:
enum LineMode { Error, Step, StackFrame };
@@ -481,7 +481,7 @@ public:
class SenderObject : public TQObject
{
- Q_OBJECT
+ TQ_OBJECT
public:
SenderObject( TQUnknownInterface *i ) : iface( i ) { iface->addRef(); }
diff --git a/tools/designer/designer/menubareditor.h b/tools/designer/designer/menubareditor.h
index 495d4112..f1d87f20 100644
--- a/tools/designer/designer/menubareditor.h
+++ b/tools/designer/designer/menubareditor.h
@@ -43,7 +43,7 @@ class TQActionGroup;
class MenuBarEditorItem : public TQObject
{
- Q_OBJECT
+ TQ_OBJECT
friend class MenuBarEditor;
@@ -87,7 +87,7 @@ class FormWindow;
class MenuBarEditor : public TQMenuBar
{
- Q_OBJECT
+ TQ_OBJECT
public:
MenuBarEditor( FormWindow * fw, TQWidget * parent = 0, const char * name = 0 );
diff --git a/tools/designer/designer/multilineeditorimpl.h b/tools/designer/designer/multilineeditorimpl.h
index 603578db..11c7233c 100644
--- a/tools/designer/designer/multilineeditorimpl.h
+++ b/tools/designer/designer/multilineeditorimpl.h
@@ -45,7 +45,7 @@ class TQTextDocument;
class TextEdit : public TQTextEdit
{
- Q_OBJECT
+ TQ_OBJECT
public:
TextEdit( TQWidget *parent = 0, const char *name = 0 );
@@ -56,7 +56,7 @@ public:
class ToolBarItem : public TQAction
{
- Q_OBJECT
+ TQ_OBJECT
public:
ToolBarItem( TQWidget *parent, TQWidget *toolBar,
@@ -75,7 +75,7 @@ private:
class MultiLineEditor : public MultiLineEditorBase
{
- Q_OBJECT
+ TQ_OBJECT
public:
MultiLineEditor( bool call_static, bool richtextMode, TQWidget *parent, TQWidget *editWidget,
diff --git a/tools/designer/designer/newformimpl.h b/tools/designer/designer/newformimpl.h
index ba9a21c8..3b941338 100644
--- a/tools/designer/designer/newformimpl.h
+++ b/tools/designer/designer/newformimpl.h
@@ -149,7 +149,7 @@ private:
class NewForm : public NewFormBase
{
- Q_OBJECT
+ TQ_OBJECT
public:
NewForm( TQIconView *templateView, const TQString &templatePath );
diff --git a/tools/designer/designer/orderindicator.h b/tools/designer/designer/orderindicator.h
index 49b144f6..1e7c8882 100644
--- a/tools/designer/designer/orderindicator.h
+++ b/tools/designer/designer/orderindicator.h
@@ -40,7 +40,7 @@ class FormWindow;
class OrderIndicator : public TQWidget
{
- Q_OBJECT
+ TQ_OBJECT
public:
OrderIndicator( int i, TQWidget* w, FormWindow* fw );
diff --git a/tools/designer/designer/outputwindow.h b/tools/designer/designer/outputwindow.h
index 991e7572..a523793b 100644
--- a/tools/designer/designer/outputwindow.h
+++ b/tools/designer/designer/outputwindow.h
@@ -68,7 +68,7 @@ private:
class OutputWindow : public TQTabWidget
{
- Q_OBJECT
+ TQ_OBJECT
public:
OutputWindow( TQWidget *parent );
diff --git a/tools/designer/designer/paletteeditoradvancedimpl.h b/tools/designer/designer/paletteeditoradvancedimpl.h
index 3abd0fc1..ab61b33e 100644
--- a/tools/designer/designer/paletteeditoradvancedimpl.h
+++ b/tools/designer/designer/paletteeditoradvancedimpl.h
@@ -40,7 +40,7 @@ class FormWindow;
class PaletteEditorAdvanced : public PaletteEditorAdvancedBase
{
- Q_OBJECT
+ TQ_OBJECT
public:
PaletteEditorAdvanced( FormWindow *fw, TQWidget * parent=0, const char * name=0,
bool modal=FALSE, WFlags f=0 );
diff --git a/tools/designer/designer/paletteeditorimpl.h b/tools/designer/designer/paletteeditorimpl.h
index a4cd675a..8ae59843 100644
--- a/tools/designer/designer/paletteeditorimpl.h
+++ b/tools/designer/designer/paletteeditorimpl.h
@@ -40,7 +40,7 @@ class FormWindow;
class PaletteEditor : public PaletteEditorBase
{
- Q_OBJECT
+ TQ_OBJECT
public:
PaletteEditor( FormWindow *fw, TQWidget * parent=0, const char * name=0, bool modal=FALSE, WFlags f=0 );
diff --git a/tools/designer/designer/pixmapchooser.h b/tools/designer/designer/pixmapchooser.h
index 4ac0cba5..22050216 100644
--- a/tools/designer/designer/pixmapchooser.h
+++ b/tools/designer/designer/pixmapchooser.h
@@ -44,7 +44,7 @@ class FormWindow;
class PixmapView : public TQScrollView,
public TQFilePreview
{
- Q_OBJECT
+ TQ_OBJECT
public:
PixmapView( TQWidget *parent );
@@ -59,7 +59,7 @@ private:
class ImageIconProvider : public TQFileIconProvider
{
- Q_OBJECT
+ TQ_OBJECT
public:
ImageIconProvider( TQWidget *parent = 0, const char *name = 0 );
diff --git a/tools/designer/designer/popupmenueditor.h b/tools/designer/designer/popupmenueditor.h
index b4335905..8143b9fa 100644
--- a/tools/designer/designer/popupmenueditor.h
+++ b/tools/designer/designer/popupmenueditor.h
@@ -43,7 +43,7 @@ class TQMenuItem;
class PopupMenuEditorItem : public TQObject
{
- Q_OBJECT
+ TQ_OBJECT
friend class PopupMenuEditor;
@@ -106,7 +106,7 @@ class TQLineEdit;
class PopupMenuEditor : public TQWidget
{
- Q_OBJECT
+ TQ_OBJECT
friend class PopupMenuEditorItem;
friend class MenuBarEditor;
diff --git a/tools/designer/designer/previewframe.h b/tools/designer/designer/previewframe.h
index 679f2081..67fabbf5 100644
--- a/tools/designer/designer/previewframe.h
+++ b/tools/designer/designer/previewframe.h
@@ -41,7 +41,7 @@
class PreviewWorkspace : public TQWorkspace
{
- Q_OBJECT
+ TQ_OBJECT
public:
PreviewWorkspace( TQWidget* parent = 0, const char* name = 0 )
: TQWorkspace( parent, name ) {}
@@ -53,7 +53,7 @@ protected:
class PreviewFrame : public TQVBox
{
- Q_OBJECT
+ TQ_OBJECT
public:
PreviewFrame( TQWidget *parent = 0, const char *name = 0 );
diff --git a/tools/designer/designer/previewwidgetimpl.h b/tools/designer/designer/previewwidgetimpl.h
index 0fff9d15..aaf51154 100644
--- a/tools/designer/designer/previewwidgetimpl.h
+++ b/tools/designer/designer/previewwidgetimpl.h
@@ -38,7 +38,7 @@
class PreviewWidget : public PreviewWidgetBase
{
- Q_OBJECT
+ TQ_OBJECT
public:
PreviewWidget( TQWidget *parent = 0, const char *name = 0 );
diff --git a/tools/designer/designer/project.h b/tools/designer/designer/project.h
index 066712c1..810e5b00 100644
--- a/tools/designer/designer/project.h
+++ b/tools/designer/designer/project.h
@@ -117,7 +117,7 @@ private:
class Project : public TQObject
{
- Q_OBJECT
+ TQ_OBJECT
friend class DatabaseConnection;
public:
diff --git a/tools/designer/designer/projectsettingsimpl.h b/tools/designer/designer/projectsettingsimpl.h
index cff46e91..639dab14 100644
--- a/tools/designer/designer/projectsettingsimpl.h
+++ b/tools/designer/designer/projectsettingsimpl.h
@@ -43,7 +43,7 @@ class SourceFile;
class ProjectSettings : public ProjectSettingsBase
{
- Q_OBJECT
+ TQ_OBJECT
public:
ProjectSettings( Project *pro, TQWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
diff --git a/tools/designer/designer/propertyeditor.h b/tools/designer/designer/propertyeditor.h
index ca7228ac..45f22481 100644
--- a/tools/designer/designer/propertyeditor.h
+++ b/tools/designer/designer/propertyeditor.h
@@ -145,7 +145,7 @@ private:
class PropertyTextItem : public TQObject,
public PropertyItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
PropertyTextItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -181,7 +181,7 @@ private:
class PropertyBoolItem : public TQObject,
public PropertyItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
PropertyBoolItem( PropertyList *l, PropertyItem *after, PropertyItem *prop, const TQString &propName );
@@ -205,7 +205,7 @@ private:
class PropertyIntItem : public TQObject,
public PropertyItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
PropertyIntItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -230,7 +230,7 @@ private:
class PropertyLayoutItem : public TQObject,
public PropertyItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
PropertyLayoutItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -254,7 +254,7 @@ private:
class PropertyDoubleItem : public TQObject,
public PropertyItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
PropertyDoubleItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -277,7 +277,7 @@ private:
class PropertyListItem : public TQObject,
public PropertyItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
PropertyListItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -312,7 +312,7 @@ private:
class PropertyFontItem : public TQObject,
public PropertyItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
PropertyFontItem( PropertyList *l, PropertyItem *after, PropertyItem *prop, const TQString &propName );
@@ -341,7 +341,7 @@ private:
class PropertyCoordItem : public TQObject,
public PropertyItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
enum Type { Rect, Size, Point };
@@ -370,7 +370,7 @@ private:
class PropertyColorItem : public TQObject,
public PropertyItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
PropertyColorItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -404,7 +404,7 @@ private:
class PropertyPixmapItem : public TQObject,
public PropertyItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
enum Type { Pixmap, IconSet, Image };
@@ -436,7 +436,7 @@ private:
class PropertySizePolicyItem : public TQObject,
public PropertyItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
PropertySizePolicyItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -462,7 +462,7 @@ private:
class PropertyPaletteItem : public TQObject,
public PropertyItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
PropertyPaletteItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -490,7 +490,7 @@ private:
class PropertyCursorItem : public TQObject,
public PropertyItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
PropertyCursorItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -514,7 +514,7 @@ private:
class PropertyKeysequenceItem : public TQObject,
public PropertyItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
PropertyKeysequenceItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -544,7 +544,7 @@ private:
class PropertyDatabaseItem : public TQObject,
public PropertyItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
PropertyDatabaseItem( PropertyList *l, PropertyItem *after, PropertyItem *prop, const TQString &propName, bool wField );
@@ -581,7 +581,7 @@ struct EnumItem {
class EnumPopup : public TQFrame
{
- Q_OBJECT
+ TQ_OBJECT
public:
EnumPopup( TQWidget *parent, const char *name, WFlags f=0 );
@@ -605,7 +605,7 @@ private:
class EnumBox : public TQComboBox
{
- Q_OBJECT
+ TQ_OBJECT
public:
EnumBox( TQWidget *parent, const char *name = 0 );
@@ -639,7 +639,7 @@ private:
class PropertyEnumItem : public TQObject,
public PropertyItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
PropertyEnumItem( PropertyList *l, PropertyItem *after, PropertyItem *prop,
@@ -665,7 +665,7 @@ private:
class PropertyList : public TQListView
{
- Q_OBJECT
+ TQ_OBJECT
public:
PropertyList( PropertyEditor *e );
@@ -727,7 +727,7 @@ private:
class EventList : public HierarchyList
{
- Q_OBJECT
+ TQ_OBJECT
public:
EventList( TQWidget *parent, FormWindow *fw, PropertyEditor *e );
@@ -754,7 +754,7 @@ private:
class PropertyEditor : public TQTabWidget
{
- Q_OBJECT
+ TQ_OBJECT
public:
PropertyEditor( TQWidget *parent );
@@ -805,7 +805,7 @@ private:
class PropertyDateItem : public TQObject,
public PropertyItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
PropertyDateItem( PropertyList *l, PropertyItem *after, PropertyItem *prop, const TQString &propName );
@@ -828,7 +828,7 @@ private:
class PropertyTimeItem : public TQObject,
public PropertyItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
PropertyTimeItem( PropertyList *l, PropertyItem *after, PropertyItem *prop, const TQString &propName );
@@ -851,7 +851,7 @@ private:
class PropertyDateTimeItem : public TQObject,
public PropertyItem
{
- Q_OBJECT
+ TQ_OBJECT
public:
PropertyDateTimeItem( PropertyList *l, PropertyItem *after, PropertyItem *prop, const TQString &propName );
diff --git a/tools/designer/designer/qcompletionedit.h b/tools/designer/designer/qcompletionedit.h
index 7bae93b8..fcc8b4ae 100644
--- a/tools/designer/designer/qcompletionedit.h
+++ b/tools/designer/designer/qcompletionedit.h
@@ -42,7 +42,7 @@ class TQVBox;
class TQCompletionEdit : public TQLineEdit
{
- Q_OBJECT
+ TQ_OBJECT
Q_PROPERTY( bool autoAdd READ autoAdd WRITE setAutoAdd )
Q_PROPERTY( bool caseSensitive READ isCaseSensitive WRITE setCaseSensitive )
diff --git a/tools/designer/designer/sizehandle.h b/tools/designer/designer/sizehandle.h
index d391ec9a..adc1d781 100644
--- a/tools/designer/designer/sizehandle.h
+++ b/tools/designer/designer/sizehandle.h
@@ -45,7 +45,7 @@ class TQPaintEvent;
class SizeHandle : public TQWidget
{
- Q_OBJECT
+ TQ_OBJECT
public:
enum Direction { LeftTop, Top, RightTop, Right, RightBottom, Bottom, LeftBottom, Left };
diff --git a/tools/designer/designer/sourceeditor.h b/tools/designer/designer/sourceeditor.h
index a41fd86c..613fb549 100644
--- a/tools/designer/designer/sourceeditor.h
+++ b/tools/designer/designer/sourceeditor.h
@@ -46,7 +46,7 @@ class SourceFile;
class SourceEditor : public TQVBox
{
- Q_OBJECT
+ TQ_OBJECT
public:
SourceEditor( TQWidget *parent, EditorInterface *iface, LanguageInterface *liface );
diff --git a/tools/designer/designer/sourcefile.h b/tools/designer/designer/sourcefile.h
index 47663c8e..b659efaa 100644
--- a/tools/designer/designer/sourcefile.h
+++ b/tools/designer/designer/sourcefile.h
@@ -43,7 +43,7 @@ class Project;
class SourceFile : public TQObject
{
- Q_OBJECT
+ TQ_OBJECT
public:
SourceFile( const TQString &fn, bool temp, Project *p );
diff --git a/tools/designer/designer/startdialogimpl.h b/tools/designer/designer/startdialogimpl.h
index c9406dc1..21d0b1df 100644
--- a/tools/designer/designer/startdialogimpl.h
+++ b/tools/designer/designer/startdialogimpl.h
@@ -46,7 +46,7 @@
class FileDialog : public TQFileDialog
{
- Q_OBJECT
+ TQ_OBJECT
public:
FileDialog( const TQString &dir, TQWidget *parent );
@@ -61,7 +61,7 @@ signals:
class StartDialog : public StartDialogBase
{
- Q_OBJECT
+ TQ_OBJECT
public:
StartDialog( TQWidget *parent, const TQString &templatePath );
diff --git a/tools/designer/designer/styledbutton.h b/tools/designer/designer/styledbutton.h
index 4574bf42..e9639d03 100644
--- a/tools/designer/designer/styledbutton.h
+++ b/tools/designer/designer/styledbutton.h
@@ -43,7 +43,7 @@ class FormWindow;
class StyledButton : public TQButton
{
- Q_OBJECT
+ TQ_OBJECT
Q_PROPERTY( TQColor color READ color WRITE setColor )
Q_PROPERTY( TQPixmap pixmap READ pixmap WRITE setPixmap )
diff --git a/tools/designer/designer/tableeditorimpl.h b/tools/designer/designer/tableeditorimpl.h
index bb688433..f566f264 100644
--- a/tools/designer/designer/tableeditorimpl.h
+++ b/tools/designer/designer/tableeditorimpl.h
@@ -43,7 +43,7 @@ class FormWindow;
class TableEditor : public TableEditorBase
{
- Q_OBJECT
+ TQ_OBJECT
public:
TableEditor( TQWidget* parent = 0, TQWidget *editWidget = 0, FormWindow *fw = 0,
diff --git a/tools/designer/designer/timestamp.h b/tools/designer/designer/timestamp.h
index b37d57f1..bdb88d80 100644
--- a/tools/designer/designer/timestamp.h
+++ b/tools/designer/designer/timestamp.h
@@ -40,7 +40,7 @@
class TimeStamp : public TQObject
{
- Q_OBJECT
+ TQ_OBJECT
public:
TimeStamp( TQObject *parent, const TQString &f );
diff --git a/tools/designer/designer/variabledialogimpl.h b/tools/designer/designer/variabledialogimpl.h
index af4564b2..adc6f964 100644
--- a/tools/designer/designer/variabledialogimpl.h
+++ b/tools/designer/designer/variabledialogimpl.h
@@ -41,7 +41,7 @@ class TQListView;
class VariableDialog : public VariableDialogBase
{
- Q_OBJECT
+ TQ_OBJECT
public:
VariableDialog( FormWindow *fw, TQWidget* parent = 0 );
~VariableDialog();
diff --git a/tools/designer/designer/widgetaction.h b/tools/designer/designer/widgetaction.h
index da500176..40017de8 100644
--- a/tools/designer/designer/widgetaction.h
+++ b/tools/designer/designer/widgetaction.h
@@ -38,7 +38,7 @@
class WidgetAction : public TQAction
{
- Q_OBJECT
+ TQ_OBJECT
public:
WidgetAction( const TQString &grp, TQObject* parent,
diff --git a/tools/designer/designer/widgetfactory.h b/tools/designer/designer/widgetfactory.h
index 59e05a99..55d22907 100644
--- a/tools/designer/designer/widgetfactory.h
+++ b/tools/designer/designer/widgetfactory.h
@@ -128,7 +128,7 @@ private:
class TQDesignerTabWidget : public TQTabWidget
{
- Q_OBJECT
+ TQ_OBJECT
Q_PROPERTY( int currentPage READ currentPage WRITE setCurrentPage STORED false DESIGNABLE true )
Q_PROPERTY( TQString pageTitle READ pageTitle WRITE setPageTitle STORED false DESIGNABLE true )
Q_PROPERTY( TQCString pageName READ pageName WRITE setPageName STORED false DESIGNABLE true )
@@ -157,7 +157,7 @@ private:
class TQDesignerWidgetStack : public TQWidgetStack
{
- Q_OBJECT
+ TQ_OBJECT
Q_PROPERTY( int currentPage READ currentPage WRITE setCurrentPage STORED false DESIGNABLE true )
Q_PROPERTY( TQCString pageName READ pageName WRITE setPageName STORED false DESIGNABLE true )
public:
@@ -200,7 +200,7 @@ private:
class TQDesignerWizard : public TQWizard
{
- Q_OBJECT
+ TQ_OBJECT
Q_PROPERTY( int currentPage READ currentPageNum WRITE setCurrentPage STORED false DESIGNABLE true )
Q_PROPERTY( TQString pageTitle READ pageTitle WRITE setPageTitle STORED false DESIGNABLE true )
Q_PROPERTY( TQCString pageName READ pageName WRITE setPageName STORED false DESIGNABLE true )
@@ -242,7 +242,7 @@ private:
class TQLayoutWidget : public TQWidget
{
- Q_OBJECT
+ TQ_OBJECT
public:
TQLayoutWidget( TQWidget *parent, const char *name ) : TQWidget( parent, name ), sp( TQWidget::sizePolicy() ) {}
@@ -260,7 +260,7 @@ protected:
class CustomWidget : public TQWidget
{
- Q_OBJECT
+ TQ_OBJECT
public:
CustomWidget( TQWidget *parent, const char *name, MetaDataBase::CustomWidget *cw )
@@ -292,7 +292,7 @@ protected:
class Line : public TQFrame
{
- Q_OBJECT
+ TQ_OBJECT
Q_PROPERTY( Orientation orientation READ orientation WRITE setOrientation )
Q_OVERRIDE( int frameWidth DESIGNABLE false )
@@ -318,7 +318,7 @@ public:
class TQDesignerLabel : public TQLabel
{
- Q_OBJECT
+ TQ_OBJECT
Q_PROPERTY( TQCString buddy READ buddyWidget WRITE setBuddyWidget )
@@ -350,7 +350,7 @@ private:
class TQDesignerWidget : public TQWidget
{
- Q_OBJECT
+ TQ_OBJECT
public:
TQDesignerWidget( FormWindow *fw, TQWidget *parent, const char *name )
@@ -370,7 +370,7 @@ private:
class TQDesignerDialog : public TQDialog
{
- Q_OBJECT
+ TQ_OBJECT
Q_OVERRIDE( bool modal READ isModal WRITE setModal )
public:
@@ -391,7 +391,7 @@ private:
class TQDesignerToolButton : public TQToolButton
{
- Q_OBJECT
+ TQ_OBJECT
Q_PROPERTY( int buttonGroupId READ buttonGroupId WRITE setButtonGroupId )
public:
@@ -414,7 +414,7 @@ public:
class TQDesignerRadioButton : public TQRadioButton
{
- Q_OBJECT
+ TQ_OBJECT
Q_PROPERTY( int buttonGroupId READ buttonGroupId WRITE setButtonGroupId )
public:
@@ -439,7 +439,7 @@ public:
class TQDesignerPushButton : public TQPushButton
{
- Q_OBJECT
+ TQ_OBJECT
Q_PROPERTY( int buttonGroupId READ buttonGroupId WRITE setButtonGroupId )
public:
@@ -463,7 +463,7 @@ public:
class TQDesignerCheckBox : public TQCheckBox
{
- Q_OBJECT
+ TQ_OBJECT
Q_PROPERTY( int buttonGroupId READ buttonGroupId WRITE setButtonGroupId )
public:
@@ -487,7 +487,7 @@ public:
class TQDesignerToolBox : public TQToolBox
{
- Q_OBJECT
+ TQ_OBJECT
Q_PROPERTY( TQString itemLabel READ itemLabel WRITE setItemLabel STORED false DESIGNABLE true )
Q_PROPERTY( TQCString itemName READ itemName WRITE setItemName STORED false DESIGNABLE true )
Q_PROPERTY( BackgroundMode itemBackgroundMode READ itemBackgroundMode WRITE setItemBackgroundMode STORED false DESIGNABLE true )
diff --git a/tools/designer/designer/wizardeditorimpl.h b/tools/designer/designer/wizardeditorimpl.h
index 983e26a8..c8326893 100644
--- a/tools/designer/designer/wizardeditorimpl.h
+++ b/tools/designer/designer/wizardeditorimpl.h
@@ -44,7 +44,7 @@ class FormWindow;
class WizardEditor : public WizardEditorBase
{
- Q_OBJECT
+ TQ_OBJECT
public:
WizardEditor( TQWidget *parent, TQWizard *wizard, FormWindow *fw );
diff --git a/tools/designer/designer/workspace.h b/tools/designer/designer/workspace.h
index e99c6f40..4f5bea13 100644
--- a/tools/designer/designer/workspace.h
+++ b/tools/designer/designer/workspace.h
@@ -93,7 +93,7 @@ private:
class Workspace : public TQListView
{
- Q_OBJECT
+ TQ_OBJECT
public:
Workspace( TQWidget *parent , MainWindow *mw );
diff --git a/tools/designer/designer/resource.cpp b/tools/designer/designer/resource.cpp
index 0e4a5206..4f6c997d 100644
--- a/tools/designer/designer/resource.cpp
+++ b/tools/designer/designer/resource.cpp
@@ -2429,13 +2429,13 @@ static TQImage loadImageData( TQDomElement &n2 )
ulong len = n2.attribute( "length" ).toULong();
if ( len < data.length() * 5 )
len = data.length() * 5;
// qUncompress() expects the first 4 bytes to be the expected length of
// the uncompressed data
ba[0] = ( len & 0xff000000 ) >> 24;
ba[1] = ( len & 0x00ff0000 ) >> 16;
ba[2] = ( len & 0x0000ff00 ) >> 8;
ba[3] = ( len & 0x000000ff );
- TQByteArray baunzip = qUncompress( ba, baSize );
+ TQByteArray baunzip = tqUncompress( ba, baSize );
img.loadFromData( (const uchar*)baunzip.data(), baunzip.size(), format.left(format.find('.')) );
} else {
img.loadFromData( (const uchar*)ba+lengthOffset, baSize-lengthOffset, format );
@@ -2429,13 +2429,13 @@ static TQImage loadImageData( TQDomElement &n2 )
if ( len < data.length() * 5 )
len = data.length() * 5;
- // qUncompress() expects the first 4 bytes to be the expected length of
+ // tqUncompress() expects the first 4 bytes to be the expected length of
// the uncompressed data
ba[0] = ( len & 0xff000000 ) >> 24;